|pypi| |actions| |codecov| |downloads|



intecomm-edc
------------


Controlling chronic diseases in Africa: Development and evaluation of an integrated community-based management model for HIV, Diabetes and Hypertension in Tanzania and Uganda (INTE-COMM study)


Liverpool School of Tropical Medicine


http://www.isrctn.com/ISRCTN15319595


See also https://github.com/clinicedc/edc



Installation
------------

... in development

.. |pypi| image:: https://img.shields.io/pypi/v/intecomm-edc.svg
    :target: https://pypi.python.org/pypi/intecomm-edc

.. |actions| image:: https://github.com/intecomm-trial/intecomm-edc/workflows/build/badge.svg?branch=develop
  :target: https://github.com/intecomm-trial/intecomm-edc/actions?query=workflow:build

.. |codecov| image:: https://codecov.io/gh/intecomm-trial/intecomm-edc/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/intecomm-trial/intecomm-edc

.. |downloads| image:: https://pepy.tech/badge/intecomm-edc
   :target: https://pepy.tech/project/intecomm-edc
